import { SGraphItem, STextItem, SLineStyle } from "@saga-web/graph/lib";
import { SPainter, SColor, SFont } from "@saga-web/draw";
import { Info } from '../types/Info';
import { ItemOrder } from '@saga-web/big/lib';
import { cloneDeep } from 'lodash'
/**
 * 信息点Item
 *
 * * @author yunxing
 */
export class SInfoItem extends STextItem {
    /** 标识对象数据 */
    data: Info;
    // 工程信息化对象列表
    AttachObjectIds: string[] = [];
    Properties: object = {}
    Code: string = '';
    /**
     * 构造函数
     *
     * @param parent    指向父对象
     * @param data      标识对象数据
     */
    constructor(parent: SGraphItem | null, data: Info) {
        super(parent);
        this.zOrder = ItemOrder.textOrder;
        this.isTransform = false;
        this.data = cloneDeep(data);
        this.id = data.ID;
        this.Code = data.Code;
        this.name = data.Name;
        this.text = data.Name
        this.AttachObjectIds = data.AttachObjectIds
        this.Properties = data.Properties
        this.moveTo(data.Pos.X, data.Pos.Y);
        if (data.Size) {
            this.width = data.Size.Width;
            this.height = data.Size.Height;
        }
        if (data.Properties && data.Properties.Color) {
            this.color = new SColor(data.Properties.Color);
        }
        if (data.Properties && data.Properties.FontSize) {
            this.font = new SFont("sans-serif", data.Properties.FontSize);;
        }
        if (data.Properties && data.Properties.Background) {
            this.backgroundColor = new SColor(data.Properties.Background);
        }
    } // Constructor
    /**
     * 返回item对应的数据
     */
    toData(): Info {
        this.data.Code = this.Code
        this.data.AttachObjectIds = this.AttachObjectIds
        this.data.Pos = { X: this.x, Y: this.y };
        this.data.Size = { Width: this.width, Height: this.height };
        this.data.Properties.Color = this.color.value;
        this.data.Properties.FontSize = this.font.size;
        this.data.Properties.Background = this.backgroundColor.value;
        return this.data;
    }
} // Class SInfoItem
